==> cscec5b-rmat-api-3.0.1-20221021.093018-17-sources.jar: com/ejianc/business/rmat/vo/ExitApplyDetailGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.math.BigDecimal;


/**
 * 推送供方明细
 * 
 * @author syj
 * 
 */
public class ExitApplyDetailGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String pId; // 退场主键ID
    private String materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private String memo; // 备注
    private String offRentDate; // 止租日
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    private BigDecimal onRentNum; // 在租数量
    private BigDecimal applyExitNum; // 申请退场数量
    private BigDecimal exitedNum; // 已退场数量

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getpId() {
        return pId;
    }

    public void setpId(String pId) {
        this.pId = pId;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(String materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getOffRentDate() {
        return offRentDate;
    }

    public void setOffRentDate(String offRentDate) {
        this.offRentDate = offRentDate;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public BigDecimal getOnRentNum() {
        return onRentNum;
    }

    public void setOnRentNum(BigDecimal onRentNum) {
        this.onRentNum = onRentNum;
    }

    public BigDecimal getApplyExitNum() {
        return applyExitNum;
    }

    public void setApplyExitNum(BigDecimal applyExitNum) {
        this.applyExitNum = applyExitNum;
    }

    public BigDecimal getExitedNum() {
        return exitedNum;
    }

    public void setExitedNum(BigDecimal exitedNum) {
        this.exitedNum = exitedNum;
    }


}

==> cscec5b-rmat-api-3.0.1-20221110.031426-84-sources.jar: com/ejianc/business/rmat/vo/ExitApplyDetailGFVO.java <==
package com.ejianc.business.rmat.vo;

import com.baomidou.mybatisplus.annotation.TableField;

import java.math.BigDecimal;


/**
 * 推送供方明细
 * 
 * @author syj
 * 
 */
public class ExitApplyDetailGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String pId; // 退场主键ID
    private String materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private String memo; // 备注
    private String offRentDate; // 止租日
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    private BigDecimal onRentNum; // 在租数量
    private BigDecimal applyExitNum; // 申请退场数量
    private BigDecimal exitedNum; // 已退场数量
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    private BigDecimal realExitNum; // 申请退场数量(实物)
    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getpId() {
        return pId;
    }

    public void setpId(String pId) {
        this.pId = pId;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(String materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getOffRentDate() {
        return offRentDate;
    }

    public void setOffRentDate(String offRentDate) {
        this.offRentDate = offRentDate;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public BigDecimal getOnRentNum() {
        return onRentNum;
    }

    public void setOnRentNum(BigDecimal onRentNum) {
        this.onRentNum = onRentNum;
    }

    public BigDecimal getApplyExitNum() {
        return applyExitNum;
    }

    public void setApplyExitNum(BigDecimal applyExitNum) {
        this.applyExitNum = applyExitNum;
    }

    public BigDecimal getExitedNum() {
        return exitedNum;
    }

    public void setExitedNum(BigDecimal exitedNum) {
        this.exitedNum = exitedNum;
    }

    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }

    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
}
